﻿Imports System.Collections.ObjectModel

Imports MindFusion.Charting
Imports MindFusion.Charting.Components
Imports MindFusion.Drawing

Imports Color = System.Drawing.Color
Imports Image = System.Drawing.Image


Public Class MainForm

	Dim bgImage As Image

	Private Sub Form1_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load

		barChart.Title = "Agricultural produce by type"

		' create sample data
		barChart.Series = GetSeriesCollection()

		' set one color per series
		barChart.Theme.CommonSeriesFills = New List(Of Brush)() From {
		 New SolidBrush(Color.FromArgb(102, 154, 204)),
		 New SolidBrush(Color.FromArgb(0, 52, 102)),
		 New SolidBrush(Color.FromArgb(206, 0, 0))
		}

		barChart.Theme.CommonSeriesStrokes = New List(Of Brush)() From {
		 New SolidBrush(Color.FromArgb(102, 154, 204)),
		 New SolidBrush(Color.FromArgb(0, 52, 102)),
		 New SolidBrush(Color.FromArgb(206, 0, 0))
		}

		' background
		barChart.BackColor = Color.OrangeRed
		bgImage = Image.FromFile("bgimage.jpg")
		barChart.PlotImage = bgImage
		barChart.PlotImageAlign = ImageAlign.MiddleLeft

		' axis appearance
		barChart.XAxis.Title = ""
		barChart.YAxis.Title = "Quantity in tons"
		barChart.Theme.AxisStroke = New SolidBrush(Color.DimGray)
		barChart.Theme.AxisLabelsBrush = New SolidBrush(Color.White)
		barChart.Theme.AxisStrokeThickness = 1

		' legend appearance
		barChart.LegendTitle = "Agricultural type"
		barChart.Theme.LegendBackground = New SolidBrush(Color.FromArgb(180, 180, 180))
		barChart.Theme.LegendBorderStroke = New SolidBrush(Color.DimGray)
		barChart.Theme.DataLabelsBrush = New SolidBrush(Color.White)
		barChart.Theme.LegendTitleBrush = New SolidBrush(Color.White)
		barChart.Theme.AxisLabelsBrush = New SolidBrush(Color.White)
		barChart.Theme.AxisTitleBrush = New SolidBrush(Color.White)
		barChart.Theme.AxisStroke = New SolidBrush(Color.White)
		barChart.Theme.LegendBorderStrokeThickness = 1
		barChart.LegendMargin = New Margins(80, 5, 5, 5)

		SetupControls()

	End Sub

	Private Sub SetupControls()
		cbLayout.SelectedIndex = CInt(barChart.BarLayout)
		cbShowScatter.Checked = barChart.ShowScatter
		cbImage.Checked = True
		cbShowX.Checked = barChart.ShowXCoordinates
		cbShowY.Checked = barChart.ShowYCoordinates
		cbShowXTicks.Checked = barChart.ShowXTicks
		cbShowYTicks.Checked = barChart.ShowYTicks
		cbAllowPan.Checked = barChart.AllowPan
		cbMoveLegend.Checked = barChart.AllowMoveLegend
		cbHorAlign.SelectedIndex = CInt(barChart.LegendHorizontalAlignment)
		cbVertAlign.SelectedIndex = CInt(barChart.LegendVerticalAlignment)
		cbZoom.Checked = barChart.AllowZoom
		tbMarginLeft.Minimum = 0
		tbMarginLeft.Maximum = barChart.Width - 100
		tbMarginLeft.Value = CInt(barChart.LegendMargin.Left)
		tbMarginTop.Minimum = 0
		tbMarginTop.Maximum = barChart.Height - 100
		tbMarginTop.Value = CInt(barChart.LegendMargin.Top)
	End Sub

	Private Function GetSeriesCollection() As ObservableCollection(Of Series)
		Dim labels = New String(3) {"Tomatoes", "Cucumbers", "Peppers", "Lettuce"}
		Dim collection As New ObservableCollection(Of Series)()
		For i As Integer = 0 To 2
			If i = 0 Then
				collection.Add(New Series2D(New Double() {10, 20, 30, 40}, New Double() {50, 40, 50, 5}, labels) With {.Title = "Traditional"})
			End If
			If i = 1 Then
				collection.Add(New Series2D(New Double() {10, 20, 30, 40}, New Double() {60, 10, 20, 80}, labels) With {.Title = "Urban"})
			End If
			If i = 2 Then
				collection.Add(New Series2D(New Double() {10, 20, 30, 40}, New Double() {0, 60, 0, 90}, labels) With {.Title = "Hydroponics"})
			End If
		Next
		Return collection
	End Function

	Private Sub cbLayout_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cbLayout.SelectedIndexChanged
		barChart.BarLayout = DirectCast(cbLayout.SelectedIndex, BarLayout)
	End Sub

	Private Sub cbShowScatter_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowScatter.CheckedChanged
		barChart.ShowScatter = cbShowScatter.Checked
	End Sub

	Private Sub cbShowX_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowY.CheckedChanged, cbShowX.CheckedChanged
		barChart.ShowXCoordinates = cbShowX.Checked
	End Sub

	Private Sub cbShowY_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowX.CheckedChanged, cbShowY.CheckedChanged
		barChart.ShowYCoordinates = cbShowY.Checked
	End Sub

	Private Sub cbShowXTicks_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowXTicks.CheckedChanged
		barChart.ShowXTicks = cbShowXTicks.Checked
	End Sub

	Private Sub cbShowYTicks_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowYTicks.CheckedChanged
		barChart.ShowYTicks = cbShowYTicks.Checked
	End Sub

	Private Sub cbAllowPan_CheckedChanged(sender As Object, e As EventArgs) Handles cbAllowPan.CheckedChanged
		barChart.AllowPan = cbAllowPan.Checked
	End Sub

	Private Sub cbMoveLegend_CheckedChanged(sender As Object, e As EventArgs) Handles cbMoveLegend.CheckedChanged
		barChart.AllowMoveLegend = cbMoveLegend.Checked
	End Sub

	Private Sub cbHorAlign_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cbHorAlign.SelectedIndexChanged
		barChart.LegendHorizontalAlignment = DirectCast(cbHorAlign.SelectedIndex, LayoutAlignment)
	End Sub

	Private Sub cbVertAlign_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cbVertAlign.SelectedIndexChanged
		barChart.LegendVerticalAlignment = DirectCast(cbVertAlign.SelectedIndex, LayoutAlignment)
	End Sub

	Private Sub tbMarginLeft_Scroll(sender As Object, e As EventArgs) Handles tbMarginLeft.Scroll
		barChart.LegendMargin = New Margins(tbMarginLeft.Value, barChart.LegendMargin.Top, 0, 0)
	End Sub

	Private Sub tbMarginTop_Scroll(sender As Object, e As EventArgs) Handles tbMarginTop.Scroll
		barChart.LegendMargin = New Margins(barChart.LegendMargin.Left, tbMarginTop.Value, 0, 0)
	End Sub

	Private Sub cbZoom_CheckedChanged(sender As Object, e As EventArgs) Handles cbZoom.CheckedChanged
		barChart.AllowZoom = cbZoom.Checked
	End Sub

	Private Sub btnResetZoom_Click(sender As Object, e As EventArgs) Handles btnResetZoom.Click
		barChart.ResetZoom()
	End Sub

	Private Sub cbImage_CheckedChanged(sender As Object, e As EventArgs) Handles cbImage.CheckedChanged
		If cbImage.Checked Then
			barChart.PlotImage = bgImage
		Else
			barChart.PlotImage = Nothing
		End If
		barChart.Invalidate()
	End Sub


End Class
